==> release-plz-v0.3.80.tar.gz: release-plz-release-plz-v0.3.80/website/docs/release-plz-in-the-wild.md <==
# Release-plz in the wild

This page shows what projects use release-plz.

## Popular projects

Here are some popular projects using release-plz:

- [SurrealDB](https://github.com/surrealdb/surrealdb/blob/567832825a9ad660b002d96030c711a5f3d6c1e7/.github/workflows/reusable_publish_version.yml#L559)
- [windows-drivers-rs](https://github.com/microsoft/windows-drivers-rs/blob/45811e309771f95d860c05a281efd42840a866cc/release-plz.toml)
- [tokei](https://github.com/XAMPPRocky/tokei/blob/476bf2a70709e9a03de2d6c0875870ca09c251d2/.github/workflows/release-plz.yaml)
- [farm](https://github.com/farm-fe/farm/blob/b4e02d43df294188749abafbe2f0da7692fffa4d/.github/workflows/release-plz.yaml)
- [cargo-generate](https://github.com/cargo-generate/cargo-generate/blob/859ecce6e1d49d9c84a9d7cc14eab130aba67a5a/.github/workflows/release-pr.yml)
- [pavex](https://github.com/LukeMathWalker/pavex/blob/0e67806d7dcd990824161fcf5ddadca925c4a87c/.github/workflows/publish.yml)
- [octocrab](https://github.com/XAMPPRocky/octocrab/blob/6004d5059bf4dffa211780fd7db9710b744a03ab/.github/workflows/release-plz.yml)
- [crux](https://github.com/redbadger/crux/blob/72ae93a4fe15011df93a251707af439771b3be12/scripts/release-pr.sh)
- [daktilo](https://github.com/orhun/daktilo/blob/9e2bb1a955d5f1e51f4b77ecef4f518ba66e06d5/.github/workflows/cd.yml#L13)
- [trillium](https://github.com/trillium-rs/trillium/blob/5d7d0ddde14006193a346c7ef7c559f09f965eaf/.github/workflows/release.yml)
- [rabbitmq-stream-rust-client](https://github.com/rabbitmq/rabbitmq-stream-rust-client/blob/551d00e2de7917917fd2db1920270fe8896cdeb6/.github/workflows/release-plz.yml)

## GitHub Action users

Here you can find all the public repositories using the release-plz GitHub action in CI:

- [GitHub search](https://github.com/search?type=code&q=path%3A*.yml+OR+path%3A*.yaml+MarcoIeni%2Frelease-plz-action%40)
- [Dependency graph](https://github.com/MarcoIeni/release-plz-action/network/dependents)

## Release-plz config files

[Here](https://github.com/search?q=path%3Arelease-plz.toml&type=code)
you can find all release-plz config files available in GitHub public repositories.

==> release-plz-v0.3.118.tar.gz: release-plz-release-plz-v0.3.118/website/docs/release-plz-in-the-wild.md <==
# Release-plz in the wild

This page shows what projects use release-plz.

## Popular projects

Here are some popular projects using release-plz:

- [SurrealDB](https://github.com/surrealdb/surrealdb/blob/567832825a9ad660b002d96030c711a5f3d6c1e7/.github/workflows/reusable_publish_version.yml#L559)
- [windows-drivers-rs](https://github.com/microsoft/windows-drivers-rs/blob/45811e309771f95d860c05a281efd42840a866cc/release-plz.toml)
- [tokei](https://github.com/XAMPPRocky/tokei/blob/476bf2a70709e9a03de2d6c0875870ca09c251d2/.github/workflows/release-plz.yaml)
- [farm](https://github.com/farm-fe/farm/blob/b4e02d43df294188749abafbe2f0da7692fffa4d/.github/workflows/release-plz.yaml)
- [cargo-generate](https://github.com/cargo-generate/cargo-generate/blob/859ecce6e1d49d9c84a9d7cc14eab130aba67a5a/.github/workflows/release-pr.yml)
- [pavex](https://github.com/LukeMathWalker/pavex/blob/0e67806d7dcd990824161fcf5ddadca925c4a87c/.github/workflows/publish.yml)
- [octocrab](https://github.com/XAMPPRocky/octocrab/blob/6004d5059bf4dffa211780fd7db9710b744a03ab/.github/workflows/release-plz.yml)
- [crux](https://github.com/redbadger/crux/blob/72ae93a4fe15011df93a251707af439771b3be12/scripts/release-pr.sh)
- [daktilo](https://github.com/orhun/daktilo/blob/9e2bb1a955d5f1e51f4b77ecef4f518ba66e06d5/.github/workflows/cd.yml#L13)
- [trillium](https://github.com/trillium-rs/trillium/blob/5d7d0ddde14006193a346c7ef7c559f09f965eaf/.github/workflows/release.yml)
- [rabbitmq-stream-rust-client](https://github.com/rabbitmq/rabbitmq-stream-rust-client/blob/551d00e2de7917917fd2db1920270fe8896cdeb6/.github/workflows/release-plz.yml)

## GitHub Action users

Here you can find all the public repositories using the release-plz GitHub action in CI:

- GitHub search [1](https://github.com/search?type=code&q=path%3A*.yml+OR+path%3A*.yaml+MarcoIeni%2Frelease-plz-action%40)
  and [2](https://github.com/search?type=code&q=path%3A*.yml+OR+path%3A*.yaml+release-plz%2Faction%40)
- [Dependency graph](https://github.com/release-plz/action/network/dependents)

## Release-plz config files

[Here](https://github.com/search?q=path%3Arelease-plz.toml&type=code)
you can find all release-plz config files available in GitHub public repositories.
